*************
WCS Utilities
*************
These functions read and interpret the WCS information from input
images and create the output WCS objects based on STWCS routines.

.. moduleauthor:: Warren Hack <help@stsci.edu>

.. automodule:: drizzlepac.wcs_functions
   :members:
   :undoc-members:
